# coding=utf-8
"""
databaseops
See https://github.com/AnkushBhise/databaseops/ for more information
"""

# Version of databaseops
__version__ = "1.0.0"

# Create imports from project to make every thing available at top level
from .mysql import MySQLOps
from .mysql import MySQLTable
